@@ -13,9 +13,13 @@ class Postgres:
         self.slot = slot
 
     def run_cmd(self, cmd):
-        execute_sync(f'psql -h {self.host} -p {self.port} -U {self.username} -d {self.dbname} -c "{cmd}"',
+        return execute_sync(f'psql -h {self.host} -p {self.port} -U {self.username} -d {self.dbname} -c "{cmd}"',
                      env=[('PGPASSWORD', self.password)])
 
     def force_switch_wal(self):
         pg_command = 'select * from pg_switch_xlog()' if self.version < 10 else 'select * from pg_switch_wal()'
         self.run_cmd(pg_command)
+
+    def shell(self):
+        execute_sync(f'psql -h {self.host} -p {self.port} -U {self.username} -d {self.dbname}',
+                     env=[('PGPASSWORD', self.password)])
