@@ -3,6 +3,7 @@ from pgkit.cli.commands.config import config
 from pgkit.cli.commands.pitr import pitr
 from pgkit.cli.commands.status import status
 from pgkit.cli.commands.list import list
+from pgkit.cli.commands.shellx import shell
 
 
 @click.group()
@@ -15,4 +16,5 @@ def main():
     cli.add_command(pitr)
     cli.add_command(status)
     cli.add_command(list)
+    cli.add_command(shell)
     cli()
